/*
 *  Copyright 2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.w14; 

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;

/**
 * <p>Java class for CT_LinearShadeProperties complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_LinearShadeProperties">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;attribute name="ang" type="{http://schemas.openxmlformats.org/drawingml/2006/main}ST_PositiveFixedAngle" />
 *       &lt;attribute name="scaled" type="{http://schemas.microsoft.com/office/word/2010/wordml}ST_OnOff" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_LinearShadeProperties")
public class CTLinearShadeProperties
{
    @XmlAttribute(name = "ang", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
    protected Integer ang;
    @XmlAttribute(name = "scaled", namespace = "http://schemas.microsoft.com/office/word/2010/wordml")
    protected String scaled;

    /**
     * Gets the value of the ang property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAng() {
        return ang;
    }

    /**
     * Sets the value of the ang property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAng(Integer value) {
        this.ang = value;
    }

    /**
     * Gets the value of the scaled property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getScaled() {
        return scaled;
    }

    /**
     * Sets the value of the scaled property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setScaled(String value) {
        this.scaled = value;
    }
}
